<?php

namespace EventPortal\Tests\Unit\Agenda\Models;

use Carbon\Carbon;
use EventPortal\Domain\Agenda\Models\Session;
use EventPortal\Tests\TestCase;
use Illuminate\Foundation\Testing\RefreshDatabase;

class SessionTest extends TestCase
{
    use RefreshDatabase;

    /** @test **/
    public function can_determine_if_time_partially_overlaps()
    {
        factory(Session::class)->create([
            'starting_at' => Carbon::parse('09:00:00'),
            'ending_at' => Carbon::parse('10:00:00'),
        ]);

        $this->assertFalse(Session::partiallyOverlaps('11:00')->exists());
        $this->assertFalse(Session::partiallyOverlaps('10:00')->exists());

        $this->assertTrue(Session::partiallyOverlaps('09:30')->exists());
    }

    /** @test **/
    public function can_determine_if_time_completely_overlaps()
    {
        factory(Session::class)->create([
            'starting_at' => Carbon::parse('09:00:00'),
            'ending_at' => Carbon::parse('10:00:00'),
        ]);

        $this->assertFalse(Session::completelyOverlaps('11:00', '11:30')->exists());
        $this->assertTrue(Session::completelyOverlaps('08:00', '11:00')->exists());
        $this->assertTrue(Session::completelyOverlaps('09:00', '10:00')->exists());
    }
}
